@@ -1,10 +1,10 @@
-# python
+"""
+illustrations for paper
+"""
 import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
 import seaborn as sns
-
-# qis
 import qis
 import yfinance as yf
 
