@@ -411,7 +411,7 @@ class UnitTests(Enum):
 
 def run_unit_test(unit_test: UnitTests):
 
-    from qis.data.yf_data import load_etf_data
+    from qis.test_data import load_etf_data
     prices = load_etf_data().dropna()
     returns = prices.asfreq('Q', method='ffill').pct_change().dropna()
 
