@@ -32,6 +32,8 @@ class PerformanceLabel(Enum):
     WITH_DDVOL = 8
     PA_DETAILED = 9
     TOTAL_DETAILED = 10
+    ARITHMETIC = 11
+    TOTAL_ARITHMETIC = 12
 
 
 def get_performance_labels(prices: Union[pd.DataFrame, pd.Series],
@@ -98,6 +100,14 @@ def get_performance_labels(prices: Union[pd.DataFrame, pd.Series],
                      f"vol={ra_vol_vormat.format(ra_perf_table.loc[index, PerfStat.VOL.to_str()])}, "
                      f"Sharpe={sharpe_format.format(ra_perf_table.loc[index, PerfStat.SHARPE.to_str()])}, "
                      f"MaxDD={ra_vol_vormat.format(ra_perf_table.loc[index, PerfStat.MAX_DD.to_str()])} ")
+        elif performance_label == PerformanceLabel.ARITHMETIC:
+            label = (f"{name}: Total={ra_vol_vormat.format(ra_perf_table.loc[index, PerfStat.TOTAL_RETURN.to_str()])}, "
+                     f"MaxDD={ra_vol_vormat.format(ra_perf_table.loc[index, PerfStat.MAX_DD.to_str()])} ")
+        elif performance_label == PerformanceLabel.TOTAL_ARITHMETIC:
+            label = (f"{name}: Total={ra_vol_vormat.format(ra_perf_table.loc[index, PerfStat.TOTAL_RETURN.to_str()])}, "
+                     f"vol={ra_vol_vormat.format(ra_perf_table.loc[index, PerfStat.VOL.to_str()])}, "
+                     f"Sharpe={sharpe_format.format(ra_perf_table.loc[index, PerfStat.SHARPE.to_str()])}, "
+                     f"MaxDD={ra_vol_vormat.format(ra_perf_table.loc[index, PerfStat.MAX_DD.to_str()])} ")
         else:
             raise NotImplementedError(f"{performance_label}")
         legend_labels.append(label)
@@ -111,8 +121,9 @@ def plot_prices(prices: Union[pd.DataFrame, pd.Series],
                 pivot_prices: pd.Series = None,
                 regime_params: BenchmarkReturnsQuantileRegimeSpecs = BenchmarkReturnsQuantileRegimeSpecs(),
                 var_format: str = '{:,.1f}',
-                digits_to_show: int = 2,
+                digits_to_show: int = 1,
                 sharpe_format: str = '{:.2f}',
+                x_date_freq: str = 'A',
                 trend_line: put.TrendLine = put.TrendLine.NONE,
                 is_log: bool = False,
                 resample_freq: str = None,
@@ -149,6 +160,7 @@ def plot_prices(prices: Union[pd.DataFrame, pd.Series],
                                title=title,
                                legend_labels=legend_labels,
                                is_log=is_log,
+                               x_date_freq=x_date_freq,
                                ax=ax,
                                **kwargs)
 
@@ -167,11 +179,12 @@ def plot_prices_with_dd(prices: Union[pd.DataFrame, pd.Series],
                         pivot_prices: pd.Series = None,
                         regime_params: BenchmarkReturnsQuantileRegimeSpecs = BenchmarkReturnsQuantileRegimeSpecs(),
                         var_format: str = '{:,.1f}',
-                        digits_to_show: int = 2,
+                        digits_to_show: int = 1,
                         sharpe_format: str = '{:.2f}',
+                        x_date_freq: str = 'A',
                         performance_label: PerformanceLabel = PerformanceLabel.WITH_DD,
                         is_log: bool = False,
-                        is_remove_xticklabels_ax1: bool = True,
+                        remove_xticklabels_ax1: bool = True,
                         title: str = 'Performance',
                         dd_title: str = 'Running Drawdown',
                         dd_legend_type: dra.DdLegendType = dra.DdLegendType.NONE,
@@ -193,6 +206,7 @@ def plot_prices_with_dd(prices: Union[pd.DataFrame, pd.Series],
                 digits_to_show=digits_to_show,
                 sharpe_format=sharpe_format,
                 performance_label=performance_label,
+                x_date_freq=x_date_freq,
                 title=title,
                 is_log=is_log,
                 ax=axs[0],
@@ -201,11 +215,12 @@ def plot_prices_with_dd(prices: Union[pd.DataFrame, pd.Series],
     dra.plot_drawdown(prices=prices,
                       perf_params=perf_params,
                       dd_legend_type=dd_legend_type,
+                      x_date_freq=x_date_freq,
                       title=dd_title,
                       ax=axs[1],
                       **kwargs)
 
-    if is_remove_xticklabels_ax1:
+    if remove_xticklabels_ax1:
         axs[0].set_xticklabels('')
 
     if regime_benchmark_str is not None and regime_params is not None:
