@@ -1,5 +1,5 @@
-import qis.file_utils
-this = dir(qis.file_utils)
+import qis.portfolio.multi_portfolio_data
+this = dir(qis.portfolio.multi_portfolio_data)
 print(this)
 for x in this:
     if not any(y in x for y in ['__', 'Dict']):
@@ -9,7 +9,7 @@ for x in this:
 print('##############################')
 import inspect
 
-all_functions = inspect.getmembers(qis.file_utils, inspect.isfunction)
+all_functions = inspect.getmembers(qis.portfolio.multi_portfolio_data, inspect.isfunction)
 for x in all_functions:
     if not any(y in x for y in ['run_unit_test', 'njit', 'NamedTuple', 'dataclass', 'skew', 'kurtosis', 'abstractmethod']):
         print(f"{x[0]},")
\ No newline at end of file
